@@ -638,8 +638,8 @@ Aquest programa està basat en ObConf que ha estat desenvolupat pels següents d
     <name>QObject</name>
     <message>
         <location filename="../archive.cpp" line="26"/>
-        <source>&quot;%1&quot; was installed to %1</source>
-        <translation>&quot;%1&quot; ha estat instal·lat a %1</translation>
+        <source>&quot;%1&quot; was installed to %2</source>
+        <translation type="unfinished">&quot;%2&quot; ha estat instal·lat a %2 {1&quot;?}</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
