@@ -393,12 +393,12 @@ D: Allestedsnærværende (på alle skriveborde)</translation>
     <message>
         <location filename="../obconf.ui" line="838"/>
         <source>&amp;Show a notification when switching desktops</source>
-        <translation>&amp;Vis en notifikation når der skiftes skrivebord</translation>
+        <translation>&amp;Vis en underretning når der skiftes skrivebord</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="845"/>
         <source>&amp;Amount of time to show the notification for:</source>
-        <translation>Visningstid for &amp;notifikationen:</translation>
+        <translation>Visningstid for &amp;underretningen:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="868"/>
@@ -638,8 +638,8 @@ Programmet er baseret på ObConf udviklet af følgende udviklere.
     <name>QObject</name>
     <message>
         <location filename="../archive.cpp" line="26"/>
-        <source>&quot;%1&quot; was installed to %1</source>
-        <translation>&quot;%1&quot; blev installeret i %1</translation>
+        <source>&quot;%1&quot; was installed to %2</source>
+        <translation>&quot;%1&quot; blev installeret på %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
