@@ -24,7 +24,7 @@
     <message>
         <location filename="../obconf.ui" line="14"/>
         <source>Window Manager Preferences</source>
-        <translation>ウィンドウマネージャの設定</translation>
+        <translation>ウィンドウマネージャーの設定</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="38"/>
@@ -50,7 +50,7 @@
     <message>
         <location filename="../obconf.ui" line="58"/>
         <source>Move &amp; Resize</source>
-        <translation>移動 &amp; リサイズ</translation>
+        <translation>移動 &amp; サイズ変更</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="68"/>
@@ -80,7 +80,7 @@
     <message>
         <location filename="../obconf.ui" line="439"/>
         <source>Moving and Resizing Windows</source>
-        <translation>ウィンドウの移動とリサイズ</translation>
+        <translation>ウィンドウの移動とサイズ変更</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="542"/>
@@ -143,7 +143,7 @@
     <message>
         <location filename="../obconf.ui" line="329"/>
         <source>All monitors</source>
-        <translation>全てのモニター</translation>
+        <translation>すべてのモニター</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="334"/>
@@ -163,7 +163,7 @@
     <message>
         <location filename="../obconf.ui" line="360"/>
         <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
-        <translation>主モニターとは 例えばウィンドウの循環をさせる際のダイアログなどをOpenbox が配置するモニターです。</translation>
+        <translation>主モニターとは 例えばウィンドウの循環をさせる際のダイアログなどを Openbox が配置するモニターです。</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="381"/>
@@ -209,7 +209,7 @@
     <message>
         <location filename="../obconf.ui" line="641"/>
         <source>When resizing terminal windows</source>
-        <translation>端末ウィンドウをリサイズするとき</translation>
+        <translation>端末ウィンドウをサイズ変更するとき</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="646"/>
@@ -224,17 +224,17 @@
     <message>
         <location filename="../obconf.ui" line="660"/>
         <source>Centered on the window</source>
-        <translation>ウィンドウの中央に</translation>
+        <translation>ウィンドウの中央</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="665"/>
         <source>Above the window</source>
-        <translation>ウィンドウの上に</translation>
+        <translation>ウィンドウの上</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="670"/>
         <source>Fixed position on screen</source>
-        <translation>画面の固定位置に</translation>
+        <translation>画面の固定位置</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="785"/>
@@ -244,7 +244,7 @@
     <message>
         <location filename="../obconf.ui" line="790"/>
         <source>Shades the window</source>
-        <translation>ウィンドウに影をつける</translation>
+        <translation>ウィンドウを巻き上げる</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="153"/>
@@ -255,13 +255,13 @@ M: Maximize
 C: Close
 S: Shade (Roll up)
 D: Omnipresent (On all desktops)</source>
-        <translation>N: ウィンドウアイコン
-L: ウィンドウラベル (タイトル)
+        <translation>N: ウィンドウのアイコン
+L: ウィンドウのラベル (タイトル)
 I: アイコン化 (最小化)
 M: 最大化
 C: 閉じる
 S: シェード化 (巻き上げる)
-D: 全てのデスクトップに表示する</translation>
+D: すべてのデスクトップに表示</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="344"/>
@@ -271,7 +271,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="1025"/>
         <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
-        <translation>ドックは&quot;dockapps&quot;のためのコンテナです。dockappを実行しない限り表示されません。Dockappsは時計やシステムトレイで使用するようなアプリケーションを提供します。</translation>
+        <translation>ドックは &quot;dockapps&quot; やドック用アプリケーションのためのコンテナです。それはdockapp を実行するまで画面に表示されません。Dockapps には時計ような物をおいたり、システムトレイのように使うことが出来ます。</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1041"/>
@@ -341,7 +341,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="1162"/>
         <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
-        <translation>ウィンドウをドックエリアに配置することを可能にする(&amp;w)</translation>
+        <translation>ウィンドウをドックエリアに配置することを可能にする(&amp;W)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1169"/>
@@ -366,22 +366,22 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="1205"/>
         <source>Keep dock &amp;above other windows</source>
-        <translation>ドックを常に他のウィンドウの前面に配置する(&amp;a)</translation>
+        <translation>ドックを常に他のウィンドウの前面に配置する(&amp;A)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1212"/>
         <source>A&amp;llow dock to be both above and below windows</source>
-        <translation>ドックを他のウィンドウの前面にも背面にも配置することを可能にする(&amp;l)</translation>
+        <translation>ドックを他のウィンドウの前面にも背面にも配置することを可能にする(&amp;L)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1219"/>
         <source>Keep dock &amp;below other windows</source>
-        <translation>ドックを常に他のウィンドウの背面に配置する(&amp;b)</translation>
+        <translation>ドックを常に他のウィンドウの背面に配置する(&amp;B)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1229"/>
         <source>Hiding</source>
-        <translation>ハイディング</translation>
+        <translation>非表示</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1235"/>
@@ -391,12 +391,12 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="1245"/>
         <source>Delay before &amp;showing:</source>
-        <translation>出現するまでの時間(&amp;s):</translation>
+        <translation>出現するまでの時間(&amp;S):</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1275"/>
         <source>&amp;Hide off screen</source>
-        <translation>スクリーンから隠す(&amp;H)</translation>
+        <translation>画面から隠す(&amp;H)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1306"/>
@@ -411,7 +411,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="103"/>
         <source>Create a theme &amp;archive (.obt)...</source>
-        <translation>テーマアーカイブ (.obt)の作成(&amp;A)...</translation>
+        <translation>テーマアーカイブ(.obt)の作成(&amp;A)...</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="120"/>
@@ -436,7 +436,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="251"/>
         <source>Menu &amp;header: </source>
-        <translation>メニューのヘッダ(&amp;H): </translation>
+        <translation>メニューのヘッダー(&amp;H): </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="261"/>
@@ -446,22 +446,22 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="271"/>
         <source>Active &amp;On-screen display: </source>
-        <translation>アクティブなオンスクリーンディスプレイ(&amp;O): </translation>
+        <translation>オンスクリーンディスプレイ内のアクティブ(&amp;O): </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="281"/>
         <source>Inactive O&amp;n-screen display: </source>
-        <translation>非アクティブなオンスクリーンディスプレイ(&amp;N): </translation>
+        <translation>オンスクリーンディスプレイ内の非アクティブ(&amp;N): </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="295"/>
         <source>Focus &amp;new windows when they appear</source>
-        <translation>新規ウィンドウが現れたときそれをフォーカスする(&amp;N)</translation>
+        <translation>新規ウィンドウが現れた時それをフォーカスする(&amp;N)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="302"/>
         <source>&amp;Place new windows under the mouse pointer</source>
-        <translation>新規ウィンドウはマウスポインタの下に配置する(&amp;P)</translation>
+        <translation>新規ウィンドウはマウスポインターの下に配置する(&amp;P)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="309"/>
@@ -486,7 +486,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="445"/>
         <source>Update the window contents while &amp;resizing</source>
-        <translation>リサイズ中もウィンドウの表示内容を更新する(&amp;R)</translation>
+        <translation>サイズ変更中もウィンドウの表示内容を更新する(&amp;R)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="452"/>
@@ -506,7 +506,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="512"/>
         <source>&amp;Amount of time to wait before switching:</source>
-        <translation>デスクトップを切り替えるまでのウェイト(&amp;A):</translation>
+        <translation>デスクトップを切り替えるまでの待機時間(&amp;A):</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="532"/>
@@ -516,7 +516,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="567"/>
         <source>Fixed &amp;y position:</source>
-        <translation>固定のY位置(&amp;Y):</translation>
+        <translation>固定の Y 位置(&amp;Y):</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="596"/>
@@ -526,7 +526,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="606"/>
         <source>Fixed &amp;x position:</source>
-        <translation>固定のX位置(&amp;X):</translation>
+        <translation>固定の X 位置(&amp;X):</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="616"/>
@@ -551,7 +551,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="756"/>
         <source>&amp;Raise windows when the mouse pointer moves over them</source>
-        <translation>マウスポインタが入ったウィンドウを前面に出す(&amp;R)</translation>
+        <translation>マウスポインターが入ったウィンドウを前面に出す(&amp;R)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="774"/>
@@ -566,7 +566,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../obconf.ui" line="838"/>
         <source>&amp;Show a notification when switching desktops</source>
-        <translation>デスクトップ切替時に通知を表示する(&amp;S)</translation>
+        <translation>デスクトップ切り替え時に通知を表示する(&amp;S)</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="845"/>
@@ -601,7 +601,7 @@ D: 全てのデスクトップに表示する</translation>
     <message>
         <location filename="../maindialog.cpp" line="76"/>
         <source>About ObConf-Qt</source>
-        <translation>OBConf-Qt について</translation>
+        <translation>ObConf-Qt について</translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="77"/>
@@ -616,14 +616,14 @@ The program is based on ObConf developed by the following developers.
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
-        <translation>Openbox の設定マネージャ
+        <translation>Openbox の設定マネージャー
 
-Copyright (c) 20142015
+Copyright (c) 2014-2015
 
 作者:
 * Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
 
-このプログラムは下記の開発者によって開発されたObConfを基に開発されています。
+このプログラムは下記の開発者によって開発された ObConf を基に開発されています。
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
@@ -638,8 +638,8 @@ Copyright (c) 20142015
     <name>QObject</name>
     <message>
         <location filename="../archive.cpp" line="26"/>
-        <source>&quot;%1&quot; was installed to %1</source>
-        <translation>&quot;%1&quot; は %1 へインストールされました</translation>
+        <source>&quot;%1&quot; was installed to %2</source>
+        <translation>&quot;%1&quot; は %2 へインストールされました</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
@@ -771,9 +771,9 @@ Copyright (c) 2003        Tim Riley
 Copyright (c) 2007        Javeed Shaikh
 Copyright (c) 2013        Hong Jen Yee (PCMan)
 
-このプログラムには全く何の保障もありません。
+このプログラムには全く何の保証もありません。
 これはフリーソフトウェアであり、あなたは定められた条件下で自由に
-再配布することができます。詳細はファイル COPYING にて。
+再配布することができます。詳細は COPYING ファイル を参照して下さい。
 
 </translation>
     </message>
