@@ -638,8 +638,8 @@ Het programma is gebaseerd op ObConf, ontwikkeld door:
     <name>QObject</name>
     <message>
         <location filename="../archive.cpp" line="26"/>
-        <source>&quot;%1&quot; was installed to %1</source>
-        <translation>&quot;%1&quot; werd geïnstalleerd op %1</translation>
+        <source>&quot;%1&quot; was installed to %2</source>
+        <translation>&quot;%1&quot; was geïnstalleerd in %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
