@@ -638,8 +638,8 @@ Ten program jest oparty na ObConf utworzonym przez następujących programistów
     <name>QObject</name>
     <message>
         <location filename="../archive.cpp" line="26"/>
-        <source>&quot;%1&quot; was installed to %1</source>
-        <translation>&quot;%1&quot; zostało zainstalowane na %1</translation>
+        <source>&quot;%1&quot; was installed to %2</source>
+        <translation>&quot;%2&quot; zostało zainstalowane w %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
