@@ -638,8 +638,8 @@ The program is based on ObConf developed by the following developers.
     <name>QObject</name>
     <message>
         <location filename="../archive.cpp" line="26"/>
-        <source>&quot;%1&quot; was installed to %1</source>
-        <translation>&quot;%1&quot; встановлено до %1</translation>
+        <source>&quot;%1&quot; was installed to %2</source>
+        <translation type="unfinished">&quot;%2&quot; встановлено до %2 {1&quot;?}</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
